grim/hgkeeper

Fix some issues I missed when merging

2019-05-03, Gary Kramlich
1aa42845f1ea
Parents e9e148c05406
Children 72c01f7b0eb2
Fix some issues I missed when merging
--- a/ssh/server.go Fri May 03 11:42:18 2019 -0500
+++ b/ssh/server.go Fri May 03 13:03:32 2019 -0500
@@ -4,8 +4,6 @@
"fmt"
"net"
- "bitbucket.org/rw_grim/hgkeeper/access"
-
log "github.com/sirupsen/logrus"
"golang.org/x/crypto/ssh"
@@ -19,7 +17,7 @@
listener net.Listener
}
-func NewServer(hostKeysPath, reposPath string) *Server {
+func NewServer(hostKeysPath, reposPath string) (*Server, error) {
s := &Server{
reposPath: reposPath,
}
--- a/setup/command.go Fri May 03 11:42:18 2019 -0500
+++ b/setup/command.go Fri May 03 13:03:32 2019 -0500
@@ -14,8 +14,8 @@
}
var (
- accessYamlFilename = "access.yaml"
- accessYamlData = `---
+ accessYmlFilename = "access.yml"
+ accessYmlData = `---
global:
init:
- admins
@@ -82,9 +82,9 @@
return err
}
- // create our access.yaml
- accessYamlPath := filepath.Join(path, accessYamlFilename)
- if err := ioutil.WriteFile(accessYamlPath, []byte(accessYamlData), 0644); err != nil {
+ // create our access.yml
+ accessYmlPath := filepath.Join(path, accessYmlFilename)
+ if err := ioutil.WriteFile(accessYmlPath, []byte(accessYmlData), 0644); err != nil {
return err
}
@@ -95,7 +95,7 @@
}
// add our files
- if err := runCmd(hg.Add(path, accessYamlFilename, readmeMdFilename)); err != nil {
+ if err := runCmd(hg.Add(path, accessYmlFilename, readmeMdFilename)); err != nil {
return err
}